"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseFormComponent = void 0;
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var router_1 = require("@angular/router");
var common_1 = require("@angular/common");
var effects_1 = require("@ngrx/effects");
var data_1 = require("@ngrx/data");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var models_1 = require("./../../../base/models");
var shared_1 = require("../../../shared");
var base_component_1 = require("./base.component");
var i0 = require("@angular/core");
var i1 = require("@angular/router");
var i2 = require("../../../shared");
var i3 = require("@angular/forms");
var i4 = require("@angular/common");
var i5 = require("@ngrx/effects");
var i6 = require("@ngrx/data");
/**
 * Componente que implementa un formulario para insertar, modificar, eliminar y/o consultar un elemento de tipo T usando el framework
 * ngrx-data
 */
var BaseFormComponent = /** @class */ (function (_super) {
    __extends(BaseFormComponent, _super);
    function BaseFormComponent(activatedRoute, messageService, formBuilder, location, actions$, entityService) {
        var _this = _super.call(this) || this;
        _this.activatedRoute = activatedRoute;
        _this.messageService = messageService;
        _this.formBuilder = formBuilder;
        _this.location = location;
        _this.actions$ = actions$;
        _this.entityService = entityService;
        _this.breadcrumb = []; // contiene la miga de pan de nuestro componente
        /*tabs properties*/
        _this.myTabs = {}; // pestañas definidas en el componente (ver registerTab() e initTabs())
        _this.loadedTab = {}; // pestañas con datos cargados (todas se cargan de forma perezosa)
        _this.destroy$ = new rxjs_1.Subject();
        console.log("base-form creado");
        _this.toolbar$ = _this.createToolbar();
        _this.breadcrumb = _this.createBreadcrumb(shared_1.FormType.Insert);
        _this.myForm = _this.createFormGroup();
        return _this;
    }
    BaseFormComponent.prototype.ngOnInit = function () {
        var id = +this.activatedRoute.snapshot.paramMap.get("id");
        this.object = this.createObject(id);
        if (this.object) {
            this.setModeUpdate(this.object);
            this.updateFormValues();
        }
        else {
            this.setModeInsert();
        }
        this.updatePageStatus();
    };
    BaseFormComponent.prototype.ngOnDestroy = function () {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    };
    /** Primer valor de la toolbar al crear el objeto BaseForm */
    BaseFormComponent.prototype.createToolbar = function () {
        return rxjs_1.of(models_1.getInitToolbar());
    };
    /** Establece el componente para editar un objeto ya existente */
    BaseFormComponent.prototype.setModeUpdate = function (object) {
        this.object = object;
        this.formType = shared_1.FormType.Update;
        this.breadcrumb = this.createBreadcrumb(shared_1.FormType.Update);
        this.toolbar$ = rxjs_1.of(models_1.getToolbarObjectLoadedDefault());
    };
    /** Establece el componente para insertar un nuevo objeto */
    BaseFormComponent.prototype.setModeInsert = function () {
        this.formType = shared_1.FormType.Insert;
    };
    /** Actualiza los valores del FormGroup con el valor actual almacenado en object */
    BaseFormComponent.prototype.updateFormValues = function () {
        this.myForm.patchValue(__assign({}, this.object));
    };
    /** Actualiza el page status en función de tres observables. El estado de envío al servidor, el posible error producido y el éxito de la operación*/
    BaseFormComponent.prototype.updatePageStatus = function () {
        var _this = this;
        this.status$ = rxjs_1.merge(this.entityService.loading$.pipe(operators_1.map(function (loading) {
            if (loading) {
                return shared_1.PageStatus.Searching;
            }
        })), effects_1.createEffect(function () {
            return _this.actions$.pipe(operators_1.map(function (action) { return action.type; }), operators_1.filter(function (actionType) { return actionType.indexOf("error") != -1; }), operators_1.map(function (action) { return shared_1.PageStatus.Error; }));
        }, { dispatch: false }), effects_1.createEffect(function () {
            return _this.actions$.pipe(operators_1.map(function (action) { return action.type; }), operators_1.filter(function (actionType) { return actionType.indexOf("success") != -1; }), operators_1.map(function (action) { return shared_1.PageStatus.FinishSearch; }));
        }, { dispatch: false }));
    };
    Object.defineProperty(BaseFormComponent.prototype, "isEditMode", {
        /** Devuelve true si el formulario edita un elemento existente, o false si inserta un nuevo elemento. */
        get: function () {
            return this.formType === shared_1.FormType.Update;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BaseFormComponent.prototype, "isDataChanged", {
        /**
         * Devuelve true si hay algún valor cambiado en la ficha.
         * Puede ser por un campo del formulario (this.myForm.dirty) o por modificaciones en elementos relacionados.
         */
        get: function () {
            return this.myForm && this.myForm.dirty;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BaseFormComponent.prototype, "isFormValid", {
        /** Devuelve true si el formulario es válido (campos validados automáticamente, elementos relacionados, etc.). */
        get: function () {
            return this.myForm && this.myForm.valid;
        },
        enumerable: false,
        configurable: true
    });
    /** Evalúa si el usuario puede desactivar/cerrar el componente sin perder cambios todavía no guardados. */
    BaseFormComponent.prototype.canDeactivate = function () {
        console.log("canDeactivate called");
        if (this.isDataChanged) {
            //si hay cambios, mostramos la ventana de diálogo
            var p = this.messageService.confirm("Hi ha canvis pendents de desar. Està segur de que vol sortir de la plana i perdre-los?");
            var o = rxjs_1.from(p);
            return o;
        }
        else {
            // si no hay cambios, no la mostramos
            console.log("canDeactivate true");
            return true;
        }
    };
    /** Controla si el usuario sale de la página abrúptamente */
    BaseFormComponent.prototype.unloadWithUnsavedChanges = function ($event) {
        console.log("unloadWithUnsavedChanges called");
        var msg = "Hi ha canvis pendents de desar. Està segur de que vol sortir de la plana i perdre-los?";
        if (this.isDataChanged) {
            ($event || window.event).returnValue = msg;
            return msg;
        }
        return undefined;
    };
    /** Método que se dispara cuando algún botón de la toolbar es pulsado */
    BaseFormComponent.prototype.onToolbarButtonPressed = function (button) {
        console.log("Button pressed:" + button);
        if (button === shared_1.BitToolbarComponent.SAVE_BUTTON) {
            this.save();
        }
        else if (button === shared_1.BitToolbarComponent.DELETE_BUTTON) {
            this.delete();
        }
        else if (button === shared_1.BitToolbarComponent.PRINT_BUTTON) {
            this.handlePrint();
        }
        else if (button === shared_1.BitToolbarComponent.HELP_BUTTON) {
            this.help();
        }
        else {
            this.otherAction(button);
        }
    };
    /** Muestra la ayuda asociada a la pantalla. */
    BaseFormComponent.prototype.help = function () { };
    /** el componente toolbar nos comunica que se ha pulsado un botón */
    BaseFormComponent.prototype.handlePrint = function () {
        window.print();
    };
    /** contiene toda la lógica para enviar el formulario al servidor*/
    /** función útil que los componentes pueden extender para hacar algo antes de enviar el formulario al servidor */
    BaseFormComponent.prototype.preSave = function () {
        return true;
    };
    BaseFormComponent.prototype.save = function () {
        var _this = this;
        console.log("save called");
        if (!this.myForm.valid) {
            var errores = shared_1.CustomValidators.validateForm(this.myForm);
            this.messageService.sendError(new shared_1.Error(null, "Error al formulari", "Error en el formulari", null, null, true, "", errores));
        }
        else {
            var newObject = __assign(__assign({}, this.object), this.myForm.value);
            if (this.preSave()) {
                console.log("presave");
                if (this.isEditMode) {
                    console.log("update object");
                    this.entityService
                        .update(newObject)
                        .pipe(operators_1.takeUntil(this.destroy$))
                        .subscribe(function (object) { return _this.postSave(object); });
                }
                else {
                    console.log("insert object");
                    this.entityService
                        .add(newObject)
                        .pipe(operators_1.takeUntil(this.destroy$))
                        .subscribe(function (object) { return _this.postSave(object); });
                }
            }
        }
    };
    /** función para qué hacer después de insertar o modificar */
    BaseFormComponent.prototype.postSave = function (object) {
        this.setModeUpdate(object); //actualizamos nuestra copia local con lo que viene del servidor
        this.myForm.patchValue(__assign({}, this.object));
        this.myForm.markAsPristine(); // el formulario vuelve a estar sincronizado con el servidor
        this.myForm.markAsUntouched();
        this.messageService.sendNotification(new shared_1.BitMessage("Informació", "Les dades s'han desat correctament."));
    };
    BaseFormComponent.prototype.preDelete = function () { };
    /** contiene la lógica para eliminar el objeto representado en el formulario */
    BaseFormComponent.prototype.delete = function () {
        this.preDelete();
        var p = this.messageService.confirm("Està segur que vol eliminar aquest registre? Aquesta acciò no es podrà desfer?");
        var local = this;
        p.then(function (confirmacion) {
            if (confirmacion) {
                local.entityService
                    .delete(local.object)
                    .pipe(operators_1.takeUntil(local.destroy$))
                    .subscribe(function () { return local.postDelete(); });
            }
        });
    };
    BaseFormComponent.prototype.postDelete = function () {
        this.messageService.sendNotification(new shared_1.BitMessage("Informació", "Les dades s'han eliminat correctament."));
        this.goBack();
    };
    /** Cualquier otra accion que no sea la típica de guardar o eliminar */
    BaseFormComponent.prototype.otherAction = function (action) { };
    /** Cierra el formulario y vuelve a la pantalla anterior. */
    BaseFormComponent.prototype.goBack = function () {
        this.location.back();
    };
    BaseFormComponent.prototype.isPreserveQueryParams = function () {
        return false;
    };
    Object.defineProperty(BaseFormComponent.prototype, "diagnostic", {
        /** Información de debug. */
        get: function () {
            return JSON.stringify(this.object);
        },
        enumerable: false,
        configurable: true
    });
    // Métodos relacionados con pestañas (tabs) //
    /** función para hacer algo si queremos al cambiar de pestaña */
    BaseFormComponent.prototype.changeTab = function (e) { };
    /** Registra una pestaña de visualización de información. */
    BaseFormComponent.prototype.registerTab = function (index, id) {
        this.myTabs[id] = index;
    };
    // inicialización de pestañas (si hay)
    BaseFormComponent.prototype.initTabs = function () {
        this.currentTab = 0;
        this.initialTab = this.activatedRoute.snapshot.params["tab"];
        for (var tab in this.myTabs) {
            var isInitial = this.isInitialTab(tab);
            this.loadedTab[tab] = isInitial;
            if (isInitial) {
                this.currentTab = this.myTabs[tab];
            }
        }
    };
    /** Indica si la pestaña correspondiente es la inicial. */
    BaseFormComponent.prototype.isInitialTab = function (tab) {
        return this.initialTab === tab;
    };
    /** Indica si la pestaña correspondiente está cargada. */
    BaseFormComponent.prototype.isLoadedTab = function (tab) {
        return this.loadedTab[tab];
    };
    BaseFormComponent.ɵfac = function BaseFormComponent_Factory(t) { return new (t || BaseFormComponent)(i0.ɵɵdirectiveInject(i1.ActivatedRoute), i0.ɵɵdirectiveInject(i2.MessageService), i0.ɵɵdirectiveInject(i3.FormBuilder), i0.ɵɵdirectiveInject(i4.Location), i0.ɵɵdirectiveInject(i5.Actions), i0.ɵɵdirectiveInject(i6.EntityCollectionServiceBase)); };
    BaseFormComponent.ɵdir = i0.ɵɵdefineDirective({ type: BaseFormComponent, hostBindings: function BaseFormComponent_HostBindings(rf, ctx) { if (rf & 1) {
            i0.ɵɵlistener("beforeunload", function BaseFormComponent_beforeunload_HostBindingHandler() { return ctx.unloadWithUnsavedChanges(); }, false, i0.ɵɵresolveWindow);
        } }, features: [i0.ɵɵInheritDefinitionFeature] });
    return BaseFormComponent;
}(base_component_1.BaseComponent));
exports.BaseFormComponent = BaseFormComponent;
(function () { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(BaseFormComponent, [{
        type: core_1.Directive
    }], function () { return [{ type: i1.ActivatedRoute }, { type: i2.MessageService }, { type: i3.FormBuilder }, { type: i4.Location }, { type: i5.Actions }, { type: i6.EntityCollectionServiceBase }]; }, { unloadWithUnsavedChanges: [{
            type: core_1.HostListener,
            args: ["window:beforeunload"]
        }] }); })();
//# sourceMappingURL=base-form.component.js.map